# Autogenerated by nbdev

d = { 'settings': { 'branch': 'main',
                'doc_baseurl': '/dreamai_dl',
                'doc_host': 'https://HamzaFarhan.github.io',
                'git_url': 'https://github.com/HamzaFarhan/dreamai_dl',
                'lib_path': 'dreamai_dl'},
  'syms': { 'dreamai_dl.core': {},
            'dreamai_dl.imports': {},
            'dreamai_dl.utils': { 'dreamai_dl.utils.default_device': ('utils.html#default_device', 'dreamai_dl/utils.py'),
                                  'dreamai_dl.utils.is_tensor': ('utils.html#is_tensor', 'dreamai_dl/utils.py'),
                                  'dreamai_dl.utils.plt_show': ('utils.html#plt_show', 'dreamai_dl/utils.py')}}}



# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/00_utils.ipynb.

# %% auto 0
__all__ = ['default_device', 'is_tensor', 'plt_show']

# %% ../nbs/00_utils.ipynb 2
from .imports import *

# %% ../nbs/00_utils.ipynb 4
def default_device(device=None):
    if device is None:
        device = torch.device("cuda:0" if torch.cuda.is_available() else "cpu")
    return device

def is_tensor(x):
    return isinstance(x, torch.Tensor)

def plt_show(im, cmap=None, title='', figsize=(7,7)):
    if path_or_str(im):
        im = rgb_read(im)
    if is_tensor(im):
        im = tensor_to_img(im)
        if is_list(im): im = im[0]
    fig=plt.figure(figsize=figsize)
    plt.imshow(im, cmap=cmap)
    plt.title(title)
    plt.show()



import timm
import torch
import torch.nn as nn
import lightning as L
import torchmetrics as TM
import torch.nn.functional as F
from torchvision.utils import make_grid
from torchvision import transforms, models
import torchvision.transforms.functional as TF
from torch.utils.data import Dataset, DataLoader

from dreamai.core import *
from dreamai.vision import *
from dreamai.imports import *

from fastai.torch_core import Module
from fastai.vision.core import imagenet_stats
from fastai.vision.core import image2tensor as img_to_tensor
from fastai.vision.learner import has_pool_type, create_head, cut_model
from fastai.layers import LinBnDrop, Flatten, AdaptiveConcatPool2d, SigmoidRange